==> eam-wshub-proxyclient-11.4-6-sources.jar: net/datastream/schemas/mp_fields/USERSETUPRESPONSIBILITYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour USERSETUPRESPONSIBILITYID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="USERSETUPRESPONSIBILITYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RESPONSIBILITYID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "USERSETUPRESPONSIBILITYID_Type", propOrder = {
    "userid",
    "responsibilityid"
})
public class USERSETUPRESPONSIBILITYID_Type {

    @XmlElement(name = "USERID", required = true)
    protected USERID_Type userid;
    @XmlElement(name = "RESPONSIBILITYID", required = true)
    protected UCODEID_Type responsibilityid;

    /**
     * Obtient la valeur de la propriété userid.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getUSERID() {
        return userid;
    }

    /**
     * Définit la valeur de la propriété userid.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setUSERID(USERID_Type value) {
        this.userid = value;
    }

    /**
     * Obtient la valeur de la propriété responsibilityid.
     * 
     * @return
     *     possible object is
     *     {@link UCODEID_Type }
     *     
     */
    public UCODEID_Type getRESPONSIBILITYID() {
        return responsibilityid;
    }

    /**
     * Définit la valeur de la propriété responsibilityid.
     * 
     * @param value
     *     allowed object is
     *     {@link UCODEID_Type }
     *     
     */
    public void setRESPONSIBILITYID(UCODEID_Type value) {
        this.responsibilityid = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/USERSETUPRESPONSIBILITYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for USERSETUPRESPONSIBILITYID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="USERSETUPRESPONSIBILITYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RESPONSIBILITYID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "USERSETUPRESPONSIBILITYID_Type", propOrder = {
    "userid",
    "responsibilityid"
})
public class USERSETUPRESPONSIBILITYID_Type {

    @XmlElement(name = "USERID", required = true)
    protected USERID_Type userid;
    @XmlElement(name = "RESPONSIBILITYID", required = true)
    protected UCODEID_Type responsibilityid;

    /**
     * Gets the value of the userid property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getUSERID() {
        return userid;
    }

    /**
     * Sets the value of the userid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setUSERID(USERID_Type value) {
        this.userid = value;
    }

    /**
     * Gets the value of the responsibilityid property.
     * 
     * @return
     *     possible object is
     *     {@link UCODEID_Type }
     *     
     */
    public UCODEID_Type getRESPONSIBILITYID() {
        return responsibilityid;
    }

    /**
     * Sets the value of the responsibilityid property.
     * 
     * @param value
     *     allowed object is
     *     {@link UCODEID_Type }
     *     
     */
    public void setRESPONSIBILITYID(UCODEID_Type value) {
        this.responsibilityid = value;
    }

}
